@@ -726,84 +726,4 @@ Draws a wireframe, either interpreted as a surface or as a mesh.
 @recipe Wireframe begin
     documented_attributes(LineSegments)...
     depth_shift = -1f-5
-end
-
-"""
-    arrows(points, directions; kwargs...)
-    arrows(x, y, u, v)
-    arrows(x::AbstractVector, y::AbstractVector, u::AbstractMatrix, v::AbstractMatrix)
-    arrows(x, y, z, u, v, w)
-    arrows(x, y, [z], f::Function)
-
-Plots arrows at the specified points with the specified components.
-`u` and `v` are interpreted as vector components (`u` being the x
-and `v` being the y), and the vectors are plotted with the tails at
-`x`, `y`.
-
-If `x, y, u, v` are `<: AbstractVector`, then each 'row' is plotted
-as a single vector.
-
-If `u, v` are `<: AbstractMatrix`, then `x` and `y` are interpreted as
-specifications for a grid, and `u, v` are plotted as arrows along the
-grid.
-
-`arrows` can also work in three dimensions.
-
-If a `Function` is provided in place of `u, v, [w]`, then it must accept
-a `Point` as input, and return an appropriately dimensioned `Point`, `Vec`,
-or other array-like output.
-"""
-@recipe Arrows (points, directions) begin
-    "Sets the color of arrowheads and lines. Can be overridden separately using `linecolor` and `arrowcolor`."
-    color = :black
-    """Scales the size of the arrow head. This defaults to
-    `0.3` in the 2D case and `Vec3f(0.2, 0.2, 0.3)` in the 3D case. For the latter
-    the first two components scale the radius (in x/y direction) and the last scales
-    the length of the cone. If the arrowsize is set to 1, the cone will have a
-    diameter and length of 1."""
-    arrowsize = automatic
-    """Defines the marker (2D) or mesh (3D) that is used as
-    the arrow head. The default for is `'▲'` in 2D and a cone mesh in 3D. For the
-    latter the mesh should start at `Point3f(0)` and point in positive z-direction."""
-    arrowhead = automatic
-    """Defines the mesh used to draw the arrow tail in 3D.
-    It should start at `Point3f(0)` and extend in negative z-direction. The default
-    is a cylinder. This has no effect on the 2D plot."""
-    arrowtail = automatic
-    """Sets the color used for the arrow tail which is represented by a line in 2D.
-    Will copy `color` if set to `automatic`.
-    """
-    linecolor = automatic
-    """Sets the linestyle used in 2D. Does not apply to 3D plots."""
-    linestyle = nothing
-    """Sets how arrows are positioned. By default arrows start at
-    the given positions and extend along the given directions. If this attribute is
-    set to `:head`, `:lineend`, `:tailend`, `:headstart` or `:center` the given
-    positions will be between the head and tail of each arrow instead."""
-    align = :origin
-    """By default the lengths of the directions given to `arrows`
-    are used to scale the length of the arrow tails. If this attribute is set to
-    true the directions are normalized, skipping this scaling."""
-    normalize = false
-    """Scales the length of the arrow tail."""
-    lengthscale = 1f0
-
-    """Defines the number of angle subdivisions used when generating
-    the arrow head and tail meshes. Consider lowering this if you have performance
-    issues. Only applies to 3D plots."""
-    quality = 32
-    markerspace = :pixel
-
-    mixin_generic_plot_attributes()...
-    mixin_shading_attributes()...
-    mixin_colormap_attributes()...
-
-    fxaa = automatic
-    """Scales the width/diameter of the arrow tail.
-    Defaults to `1` for 2D and `0.05` for the 3D case."""
-    linewidth = automatic
-    """Sets the color of the arrow head. Will copy `color` if set to `automatic`."""
-    arrowcolor = automatic
-    "Controls whether marker attributes get transformed by the model matrix."
-    transform_marker = automatic
-end
+end
\ No newline at end of file
